@@ -37,9 +37,7 @@
  * most of functions, making it easy to chain function calls.
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include <stdlib.h>
 #include <string.h>
@@ -171,7 +169,7 @@ json_builder_is_valid_add_mode (JsonBuilder *builder)
  * json_builder_new:
  *
  * Creates a new #JsonBuilder. You can use this object to generate a
- * JSON tree and obtain the root #JsonNode<!-- -->s.
+ * JSON tree and obtain the root #JsonNode.
  *
  * Return value: the newly created #JsonBuilder instance
  */
