@@ -25,7 +25,6 @@
 #define __JSON_GOBJECT_H__
 
 #include <json-glib/json-types.h>
-#include <glib-object.h>
 
 G_BEGIN_DECLS
 
@@ -50,7 +49,7 @@ typedef struct _JsonSerializableIface   JsonSerializableIface;
  * @set_property: virtual function for setting a property
  * @get_property: virtual function for getting a property
  *
- * Interface that allows serializing and deserializing #GObject<!-- -->s
+ * Interface that allows serializing and deserializing #GObject instances
  * with properties storing complex data types. The json_serialize_gobject()
  * function will check if the passed #GObject implements this interface,
  * so it can also be used to override the default property serialization
@@ -84,33 +83,42 @@ struct _JsonSerializableIface
                                         GValue           *value);
 };
 
-GType     json_serializable_get_type (void) G_GNUC_CONST;
+JSON_AVAILABLE_IN_1_0
+GType json_serializable_get_type (void) G_GNUC_CONST;
 
+JSON_AVAILABLE_IN_1_0
 JsonNode *json_serializable_serialize_property           (JsonSerializable *serializable,
                                                           const gchar      *property_name,
                                                           const GValue     *value,
                                                           GParamSpec       *pspec);
+JSON_AVAILABLE_IN_1_0
 gboolean  json_serializable_deserialize_property         (JsonSerializable *serializable,
                                                           const gchar      *property_name,
                                                           GValue           *value,
                                                           GParamSpec       *pspec,
                                                           JsonNode         *property_node);
 
+JSON_AVAILABLE_IN_1_0
 GParamSpec *    json_serializable_find_property         (JsonSerializable *serializable,
                                                          const char       *name);
+JSON_AVAILABLE_IN_1_0
 GParamSpec **   json_serializable_list_properties       (JsonSerializable *serializable,
                                                          guint            *n_pspecs);
+JSON_AVAILABLE_IN_1_0
 void            json_serializable_set_property          (JsonSerializable *serializable,
                                                          GParamSpec       *pspec,
                                                          const GValue     *value);
+JSON_AVAILABLE_IN_1_0
 void            json_serializable_get_property          (JsonSerializable *serializable,
                                                          GParamSpec       *pspec,
                                                          GValue           *value);
 
+JSON_AVAILABLE_IN_1_0
 JsonNode *json_serializable_default_serialize_property   (JsonSerializable *serializable,
                                                           const gchar      *property_name,
                                                           const GValue     *value,
                                                           GParamSpec       *pspec);
+JSON_AVAILABLE_IN_1_0
 gboolean  json_serializable_default_deserialize_property (JsonSerializable *serializable,
                                                           const gchar      *property_name,
                                                           GValue           *value,
@@ -141,38 +149,48 @@ typedef JsonNode *(* JsonBoxedSerializeFunc) (gconstpointer boxed);
  */
 typedef gpointer (* JsonBoxedDeserializeFunc) (JsonNode *node);
 
+JSON_AVAILABLE_IN_1_0
 void      json_boxed_register_serialize_func   (GType                    gboxed_type,
                                                 JsonNodeType             node_type,
                                                 JsonBoxedSerializeFunc   serialize_func);
+JSON_AVAILABLE_IN_1_0
 void      json_boxed_register_deserialize_func (GType                    gboxed_type,
                                                 JsonNodeType             node_type,
                                                 JsonBoxedDeserializeFunc deserialize_func);
+JSON_AVAILABLE_IN_1_0
 gboolean  json_boxed_can_serialize             (GType                    gboxed_type,
                                                 JsonNodeType            *node_type);
+JSON_AVAILABLE_IN_1_0
 gboolean  json_boxed_can_deserialize           (GType                    gboxed_type,
                                                 JsonNodeType             node_type);
+JSON_AVAILABLE_IN_1_0
 JsonNode *json_boxed_serialize                 (GType                    gboxed_type,
                                                 gconstpointer            boxed);
+JSON_AVAILABLE_IN_1_0
 gpointer  json_boxed_deserialize               (GType                    gboxed_type,
                                                 JsonNode                *node);
 
+JSON_AVAILABLE_IN_1_0
 JsonNode *json_gobject_serialize               (GObject                 *gobject);
+JSON_AVAILABLE_IN_1_0
 GObject * json_gobject_deserialize             (GType                    gtype,
                                                 JsonNode                *node);
 
+JSON_AVAILABLE_IN_1_0
 GObject * json_gobject_from_data               (GType                    gtype,
                                                 const gchar             *data,
                                                 gssize                   length,
                                                 GError                 **error);
+JSON_AVAILABLE_IN_1_0
 gchar *   json_gobject_to_data                 (GObject                 *gobject,
                                                 gsize                   *length);
 
-JSON_DEPRECATED_FOR(json_gobject_from_data)
+JSON_DEPRECATED_IN_1_0_FOR(json_gobject_from_data)
 GObject * json_construct_gobject               (GType                    gtype,
                                                 const gchar             *data,
                                                 gsize                    length,
                                                 GError                 **error);
-JSON_DEPRECATED_FOR(json_gobject_to_data)
+JSON_DEPRECATED_IN_1_0_FOR(json_gobject_to_data)
 gchar *   json_serialize_gobject               (GObject                 *gobject,
                                                 gsize                   *length) G_GNUC_MALLOC;
 
